@@ -61,6 +61,8 @@ class CommandEntry : public WorksheetEntry
     QString currentLine();
 
     bool isEmpty() override;
+    bool isExcludedFromExecution();
+    bool isResultCollapsed();
 
     void setContent(const QString& content) override;
     void setContent(const QDomElement& content, const KZip& file) override;
@@ -82,7 +84,8 @@ class CommandEntry : public WorksheetEntry
 
     bool focusEntry(int pos = WorksheetTextItem::TopLeft, qreal xCoord = 0) override;
 
-    void layOutForWidth(qreal w, bool force = false) override;
+    void layOutForWidth(qreal entry_zone_x, qreal w, bool force = false) override;
+    qreal promptItemWidth();
 
     WorksheetTextItem* highlightItem() override;
 
@@ -96,9 +99,14 @@ class CommandEntry : public WorksheetEntry
     void addInformation();
     void removeResults();
     void removeResult(Cantor::Result* result);
+    void collapseResults();
+    void expandResults();
+    void excludeFromExecution();
+    void addToExecution();
 
     void showCompletion() override;
-    void selectPreviousCompletion();
+    void handleTabPress();
+    void handleBacktabPress();
     void updateEntry() override;
     void updatePrompt(const QString& postfix = CommandEntry::Prompt);
     void expressionChangedStatus(Cantor::Expression::Status status);
@@ -126,6 +134,8 @@ class CommandEntry : public WorksheetEntry
     QPoint getPopupPosition();
     QPoint toGlobalPosition(QPointF localPos);
     void initMenus();
+    void handleExistedCompletionBox();
+    void makeCompletion(const QString& line, int position);
 
   private:
     enum CompletionMode {
@@ -136,8 +146,6 @@ class CommandEntry : public WorksheetEntry
     void invalidate();
     void resultDeleted();
     void clearResultItems();
-    void collapseResults();
-    void expandResults();
     void removeResultItem(int index);
     void replaceResultItem(int index);
     void updateCompletions();
@@ -157,6 +165,7 @@ class CommandEntry : public WorksheetEntry
     void setMidPrompt();
     void setHidePrompt();
 
+
   private:
     static const double HorizontalSpacing;
     static const double VerticalSpacing;
@@ -186,6 +195,10 @@ class CommandEntry : public WorksheetEntry
     QColor m_defaultDefaultTextColor;
     QMenu* m_textColorMenu;
     QMenu* m_fontMenu;
+
+    bool m_isExecutionEnabled;
+    QColor m_activeExecutionTextColor;
+    QColor m_activeExecutionBackgroundColor;
 };
 
 #endif // COMMANDENTRY_H
