@@ -89,8 +89,8 @@ class WorksheetEntry : public QGraphicsObject
 
     virtual bool focusEntry(int pos = WorksheetTextItem::TopLeft, qreal xCoord = 0);
 
-    virtual qreal setGeometry(qreal x, qreal y, qreal w);
-    virtual void layOutForWidth(qreal w, bool force = false) = 0;
+    virtual qreal setGeometry(qreal x, qreal entry_zone_x, qreal y, qreal w);
+    virtual void layOutForWidth(qreal entry_zone_x, qreal w, bool force = false) = 0;
     QPropertyAnimation* sizeChangeAnimation(QSizeF s = QSizeF());
 
     virtual void populateMenu(QMenu* menu, QPointF pos);
@@ -127,6 +127,7 @@ class WorksheetEntry : public QGraphicsObject
     void insertLatexEntry();
     void insertImageEntry();
     void insertPageBreakEntry();
+    void insertHorizontalRuleEntry();
 
     void insertCommandEntryBefore();
     void insertTextEntryBefore();
@@ -134,6 +135,7 @@ class WorksheetEntry : public QGraphicsObject
     void insertLatexEntryBefore();
     void insertImageEntryBefore();
     void insertPageBreakEntryBefore();
+    void insertHorizontalRuleEntryBefore();
 
     void convertToCommandEntry();
     void convertToTextEntry();
@@ -141,6 +143,7 @@ class WorksheetEntry : public QGraphicsObject
     void convertToLatexEntry();
     void convertToImageEntry();
     void converToPageBreakEntry();
+    void convertToHorizontalRuleEntry();
 
     virtual void sizeAnimated();
     virtual void startRemoving();
@@ -167,6 +170,12 @@ class WorksheetEntry : public QGraphicsObject
   Q_SIGNALS:
     void aboutToBeDeleted();
 
+  public:
+    // Colors for colors menus;
+    static constexpr int colorsCount = 26;
+    static QColor colors[colorsCount];
+    static QString colorNames[colorsCount];
+
   protected:
     Worksheet* worksheet();
     WorksheetView* worksheetView();
@@ -210,6 +219,7 @@ class WorksheetEntry : public QGraphicsObject
 
   private:
     QSizeF m_size;
+    qreal m_entry_zone_x;
     WorksheetEntry* m_prev;
     WorksheetEntry* m_next;
     Q_PROPERTY(QSizeF size READ size WRITE setSize)
